==> script.simkl-2.2.0.zip: script.simkl/README.md <==
# Simkl scrobbler (for Kodi)
[![](https://img.shields.io/badge/licence-%20GPLv3-brightgreen.svg)][license] [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/SIMKL/script.simkl/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/SIMKL/script.simkl/?branch=master) [![Build Status](https://scrutinizer-ci.com/g/SIMKL/script.simkl/badges/build.png?b=master)](https://scrutinizer-ci.com/g/SIMKL/script.simkl/build-status/master) [![Crowdin](https://d322cqt584bo4o.cloudfront.net/Kodi-add-on-for-Simkl/localized.svg)](https://crowdin.com/project/Kodi-add-on-for-Simkl)


## Installing from Kodi
1. Open Kodi. Then go to System » Settings » Add-ons » Install from repository » Services » Simkl TV Tracker and click Install
2. Now it should show a prompt with instructions to Login. If this doesn't happen, go to Settings » Add-ons » My Add-ons » Services » Simkl » Configure » LogIn
3. Please report any bugs [here](https://github.com/SIMKL/script.simkl/issues)

## Installing Manually
1. Download the .zip [here](https://github.com/SIMKL/script.simkl/releases/latest)
2. Open Kodi and go to Settings > Add-ons > Install from zip file, select the zip file
3. In Settings > Add-ons > My add-ons and search for Simkl TV Tracker. Click on it.
4. Click on Configure to configure the add-on (Login and scrobbler options)
5. Please report any bugs [here](https://github.com/SIMKL/script.simkl/issues)

## TODO:
- [x] Make it work on Android

## Help Translate:
You can use Crowdin [https://crowdin.com/project/Kodi-add-on-for-Simkl](https://crowdin.com/project/Kodi-add-on-for-Simkl) to help translate this add-on into your language.

## Donations:
It would be very nice if you invite me for a cup of coffee:

Bitcoin address: 1PcbSQrBddJszsTiRhqHyLntp7Lxfuyaio

Thanks, you can write me an e-mail to david@ddavo.me with your receipt, and I'll send you a photo drinking the cup of coffee you invited me to.

## Join the conversation:
- Discuss on Discord https://discord.gg/JRtwsfG
- Post bugs, feature requests on Github https://github.com/SIMKL/script.simkl/issues

[license]: https://github.com/SIMKL/script.simkl/blob/master/LICENSE.txt

==> script.simkl-3.1.0.zip: script.simkl/README.md <==
# Simkl scrobbler (for Kodi)
[![](https://img.shields.io/badge/licence-%20GPLv3-brightgreen.svg)][license] [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/SIMKL/script.simkl/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/SIMKL/script.simkl/?branch=master) [![Build Status](https://scrutinizer-ci.com/g/SIMKL/script.simkl/badges/build.png?b=master)](https://scrutinizer-ci.com/g/SIMKL/script.simkl/build-status/master) [![Crowdin](https://d322cqt584bo4o.cloudfront.net/Kodi-add-on-for-Simkl/localized.svg)](https://crowdin.com/project/Kodi-add-on-for-Simkl)


## Installing from Kodi
1. Open Kodi. Then go to System » Settings » Add-ons » Install from repository » Kodi Add-on repository » Services » Simkl TV Tracker and click Install
2. Now it should show a prompt with instructions to Login. If this doesn't happen, go to Settings » Add-ons » My Add-ons » Services » Simkl » Configure » LogIn
3. Please report any bugs [here](https://github.com/SIMKL/script.simkl/issues)

## Installing Manually
1. Download the .zip [here](https://github.com/SIMKL/script.simkl/releases/latest)
2. Open Kodi and go to Settings > Add-ons > Install from zip file, select the zip file
3. In Settings > Add-ons > My add-ons and search for Simkl TV Tracker. Click on it.
4. Click on Configure to configure the add-on (Login and scrobbler options)
5. Please report any bugs [here](https://github.com/SIMKL/script.simkl/issues)

## TODO:
- [x] Make it work on Android

## Help Translate:
You can use Crowdin [https://crowdin.com/project/Kodi-add-on-for-Simkl](https://crowdin.com/project/Kodi-add-on-for-Simkl) to help translate this add-on into your language.

## Donations:
It would be very nice if you invite me for a cup of coffee:

Bitcoin address: 1PcbSQrBddJszsTiRhqHyLntp7Lxfuyaio

Thanks, you can write me an e-mail to david@ddavo.me with your receipt, and I'll send you a photo drinking the cup of coffee you invited me to.

## Join the conversation:
- Discuss on Discord https://discord.gg/JRtwsfG
- Post bugs, feature requests on Github https://github.com/SIMKL/script.simkl/issues

[license]: https://github.com/SIMKL/script.simkl/blob/master/LICENSE.txt
